%main(run_estimation,run_heatmap,run_bootstrap)
%performs the anlysis and plots the results regarding the paper
%``Enhanced production of heterologous proteins by a synthetic microbial 
%community: Conditions and trade-offs'',
%Marco Mauri, Jean-Luc Gouz, Hidde de Jong, Eugenio Cinquemani
%
%Inputs:
%run_estimation, 0 imports already estimated parameters (to speed up evaluation) without plotting the results, 
%1 estimates parameters from data and plots the results, 2 plots a previously stored estimation and imports the estimated parameters
%run_heatmap, 0 does not produce the steady state analysis as function of (D,Gin),
%1 estimates the steady states and plots the results, 2 plots a previously stored analysis
%run_bootstrap, 0 suppresses the a-posteriori identifiability analysis of the estimated parameters,
%1 performs the a-posteriori identifiability analysis via bootstrapping and
%plots the results, 2 imports a previously saved analysis and plots the results 
%
%This file was written by Marco Mauri, 2019
%

function main(run_estimation,run_heatmap,run_bootstrap)

%% add paths
addpath(genpath('script'));

%% dynamics
batchChemFed = 1; %0 batch, 1 chemostat, 2 fedbatch
producer = 1; %0 without producer, 1 with producer
cleaner = 1; %0 without cleaner, 1 with cleaner
hproteinP = 1; %without H protein, 1 with H protein
[T,X,dx,r] = dynamics(run_estimation,batchChemFed,producer,cleaner,hproteinP);

%% model validation
figure('units','normalized','outerposition',[0 0 1 1])

% plot from Enjalbert et al.
enjalbertData
% plot from Basan et al.
basanData
% plot from Steinsiek et al.
bettenbrockData


%% D Gin map
if run_heatmap==1 || run_heatmap==2
    plot_heatmap = 1;
    plot_rates = 1;
    DGinMap(run_heatmap,plot_heatmap,plot_rates)
end

%% fed batch
fedbatch

%% generate a-posteriori identifiability analysis
if run_bootstrap==1 || run_bootstrap==2
    bootstrap_fit(run_bootstrap)
end

end
